#-----------------------------------------------------------------------
# File    : lvq.mak
# Contents: commands to build learning vector quantization programs
# Author  : Christian Borgelt
# History : 2003.02.02 file created
#           2003.08.11 adapted to new module attmap
#           2003.08.12 adapted to new module nstats
#           2003.08.15 adapted to new module radfn
#           2006.07.20 adapted to Visual Studio 8
#           2007.03.16 special matrix versions removed
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
THISDIR  = ..\..\lvq\src
UTILDIR  = ..\..\util\src
MATHDIR  = ..\..\math\src
MATDIR   = ..\..\matrix\src
TABLEDIR = ..\..\table\src

CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _CONSOLE /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(MATHDIR) /I $(UTILDIR) /I $(MATDIR) /I $(TABLEDIR)

LD       = link.exe
LDFLAGS  = /nologo /subsystem:console /incremental:no
LIBS     = 

HDRS_1   = $(UTILDIR)\fntypes.h    $(UTILDIR)\nstats.h     \
           $(UTILDIR)\scanner.h    $(MATHDIR)\radfn.h      \
           $(MATDIR)\matrix.h      $(TABLEDIR)\attset.h    \
           $(TABLEDIR)\attmap.h    $(TABLEDIR)\table.h
HDRS     = $(HDRS_1)               $(UTILDIR)\error.h      \
           $(UTILDIR)\tabread.h    $(UTILDIR)\tabwrite.h lvq.h
OBJS     = $(UTILDIR)\arrays.obj   $(UTILDIR)\escape.obj   \
           $(UTILDIR)\tabread.obj  $(UTILDIR)\tabwrite.obj \
           $(UTILDIR)\scanner.obj  $(UTILDIR)\nst_pars.obj \
           $(MATHDIR)\gamma.obj    $(MATHDIR)\radfn.obj    \
           $(MATDIR)\mat_rdwr.obj  $(MATDIR)\matrix2.obj   \
           $(TABLEDIR)\attset1.obj $(TABLEDIR)\attset2.obj \
           $(TABLEDIR)\attset3.obj $(TABLEDIR)\attmap.obj  \
           $(TABLEDIR)\table1.obj  lvq.obj
LVQT_O   = $(OBJS)                 $(UTILDIR)\random.obj   \
           $(UTILDIR)\params.obj   $(TABLEDIR)\tab2rm.obj lvqt.obj
LVQX_O   = $(OBJS)                 $(TABLEDIR)\tab2ro.obj lvqx.obj
PRGS     = lvqt.exe lvqx.exe

#-----------------------------------------------------------------------
# Build Programs
#-----------------------------------------------------------------------
all:          $(PRGS)

lvqt.exe:     $(LVQT_O) lvq.mak
	$(LD) $(LDFLAGS) $(LVQT_O) $(LIBS) /out:$@

lvqx.exe:     $(LVQX_O) lvq.mak
	$(LD) $(LDFLAGS) $(LVQX_O) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Programs
#-----------------------------------------------------------------------
lvqt.obj:     $(HDRS) $(UTILDIR)\random.h $(UTILDIR)\params.h
lvqt.obj:     lvqt.c lvq.mak
	$(CC) $(CFLAGS) $(INCS) lvqt.c /Fo$@

lvqx.obj:     $(HDRS)
lvqx.obj:     lvqx.c lvq.mak
	$(CC) $(CFLAGS) $(INCS) lvqx.c /Fo$@

#-----------------------------------------------------------------------
# Learning Vector Quantization Management
#-----------------------------------------------------------------------
lvq.obj:      $(HDRS_1)
lvq.obj:      lvq.h lvq.c lvq.mak
	$(CC) $(CFLAGS) $(INCS) /D LVQ_PARSE lvq.c /Fo$@

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(MATHDIR)\gamma.obj:
	cd $(MATHDIR)
	$(MAKE) /f math.mak gamma.obj
	cd $(THISDIR)
$(MATHDIR)\radfn.obj:
	cd $(MATHDIR)
	$(MAKE) /f math.mak radfn.obj
	cd $(THISDIR)
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\nst_pars.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak nst_pars.obj
	cd $(THISDIR)
$(UTILDIR)\escape.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak escape.obj
	cd $(THISDIR)
$(UTILDIR)\tabread.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabread.obj
	cd $(THISDIR)
$(UTILDIR)\tabwrite.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabwrite.obj
	cd $(THISDIR)
$(UTILDIR)\scanner.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak scanner.obj
	cd $(THISDIR)
$(UTILDIR)\random.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak random.obj
	cd $(THISDIR)
$(UTILDIR)\params.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak params.obj
	cd $(THISDIR)
$(MATDIR)\mat_rdwr.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak mat_rdwr.obj
	cd $(THISDIR)
$(MATDIR)\matrix1.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix1.obj
	cd $(THISDIR)
$(MATDIR)\matrix2.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset2.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset3.obj
	cd $(THISDIR)
$(TABLEDIR)\attmap.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attmap.obj
	cd $(THISDIR)
$(TABLEDIR)\table1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table1.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2ro.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2ro.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2rm.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2rm.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy *.exe ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f lvq.mak localclean
	cd $(MATHDIR)
	$(MAKE) /f math.mak clean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(MATDIR)
	$(MAKE) /f matrix.mak localclean
	cd $(TABLEDIR)
	$(MAKE) /f table.mak localclean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch $(PRGS)
